# Generated by Django 4.1.9 on 2023-05-13 16:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nb_risk', '0004_alter_vulnerability_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='vulnerability',
            name='cvssbaseScore',
            field=models.FloatField(blank=True, max_length=100, null=True),
        ),
    ]
