# Generated by Django 4.1.5 on 2023-05-10 13:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('nb_risk', '0003_control'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='vulnerability',
            options={'verbose_name': 'Vulnerability', 'verbose_name_plural': 'Vulnerabilities'},
        ),
    ]
