<a href="{% url 'plugins:nb_risk:vulnerabilityassignment_add' %}?asset_object_type={{ object|content_type_id }}&asset_id={{ object.pk }}&return_url={{ object.get_absolute_url }}" class="btn btn-primary btn-sm">
    <i class="mdi mdi-spider" aria-hidden="true"></i>
    Assign Vulnerabilitiy
</a>
