# Generated by Django 4.1.10 on 2023-08-20 02:18

from django.db import migrations, models
import django.db.models.functions.text


class Migration(migrations.Migration):

    dependencies = [
        ('nb_risk', '0006_vulnerability_unique_vuln_name'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='vulnerability',
            name='unique_vuln_name',
        ),
        migrations.AddConstraint(
            model_name='vulnerability',
            constraint=models.UniqueConstraint(django.db.models.functions.text.Lower('name'), name='unique_vuln_name'),
        ),
    ]
