{% extends 'generic/object_list.html' %}

{% block extra_controls %}
<a href="{% url 'plugins:nb_risk:vulnerability_search' %}" type="button" class="btn btn-sm btn-primary">
    <i class="mdi mdi-magnify"></i> Search
</a>
{% endblock %}