# Generated by Django 4.1.9 on 2023-05-13 17:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nb_risk', '0005_alter_vulnerability_cvssbasescore'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='vulnerability',
            constraint=models.UniqueConstraint(fields=('name',), name='unique_vuln_name'),
        ),
    ]
