# Generated by Django 4.1.5 on 2023-04-21 00:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nb_risk', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='vulnerability',
            name='cvssaccessComplexity',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='vulnerability',
            name='cvssaccessVector',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='vulnerability',
            name='cvssauthentication',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='vulnerability',
            name='cvssavailabilityImpact',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='vulnerability',
            name='cvssbaseScore',
            field=models.FloatField(blank=True, default=0, max_length=100),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='vulnerability',
            name='cvssconfidentialityImpact',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='vulnerability',
            name='cvssintegrityImpact',
            field=models.CharField(blank=True, max_length=100),
        ),
    ]
